/*

File IKIconPath.h

Release 1.2, 7 June 1994
Copyright (C) 1994 by H. Scott Roy

This code is part of IconKit, a general toolbox for drag-and-drop applications.  IconKit is free for noncommercial use, but costs money for a commercial license.  You should have received a copy of the license agreement with this file.  If not, a copy of the license and the complete source of IconKit can be obtained from the author:

		H. Scott Roy
		2573 Stowe Ct.
		Northbrook, IL  60062-8103
		iconkit@cs.stanford.edu

For your editing convenience, this file is best viewed using an editor that automatically wraps long lines, in a fixed point font at 80 columns, with tabs every 4 spaces.

*/


/* ========================================================================== */


/*

This class provides a matrix of IKCells.  It extends the event handling of an ordinary matrix to allow dragging and editing of individual icon cells.

*/

#import <appkit/Matrix.h>


/* ========================================================================== */


@interface IKIconPath : Matrix
{
	id
		current,
		last;
}


- initFrame: (const NXRect *) frameRect;
- initFrame: (const NXRect *) frameRect
		mode: (int) aMode
		cellClass: class
		numRows: (int) rows  numCols: (int) cols;

- mouseDown: (NXEvent *) event;
- editCell: cell;
- editCellAt: (int) row  : (int) col;
- endEditing;
- resetCursorRects;
- cellWithDelegate: delegate;
- objectInColumn: (int) n;
- (const char *) stringValue;

- (NXDragOperation) draggingSourceOperationMaskForLocal: (BOOL) isLocal;
- (NXDragOperation)	draggingEntered: (id <NXDraggingInfo>) sender;
- (NXDragOperation)	draggingUpdated: (id <NXDraggingInfo>) sender;
- draggingExited: (id <NXDraggingInfo>) sender;
- (BOOL) enteredNewCell: (NXPoint) where;
- (NXDragOperation)	cellEntered: (id <NXDraggingInfo>) sender;
- (NXDragOperation)	cellUpdated: (id <NXDraggingInfo>) sender;
- cellExited: (id <NXDraggingInfo>) sender;
- (BOOL) prepareForDragOperation: (id <NXDraggingInfo>) sender;
- (BOOL) performDragOperation: (id <NXDraggingInfo>) sender;
- concludeDragOperation: (id <NXDraggingInfo>) sender;

/*
	-NO NEW DOCUMENTATION-

- initFrame: (const NXRect *) frameRect
		mode: (int) aMode
		prototype: class
		numRows: (int) rows  numCols: (int) cols

- awake;
- drawCellAt: (int) row  : (int) col;
- drawCellInside: cell;
- setCellSize: (const NXSize *) size;
- setIntercell: (const NXSize *) size;
- sizeTo: (float) width  : (float) height;
- getSelectedCells: selection;
- (BOOL) shouldDelayWindowOrderingForEvent: (NXEvent *) theEvent;

*/

@end


/* ========================================================================== */


@interface Object (IKIconPathCellDelegate)

- (const char *) path;

@end
